@@ -243,6 +243,7 @@ class Step:
         with_param: generate parallel steps with respect to a list as a
             parameter
         continue_on_failed: continue if the step fails
+        continue_on_error: continue if the step meets error
         continue_on_num_success: continue if the success number of the
             generated parallel steps greater than certain number
         continue_on_success_ratio: continue if the success ratio of the
@@ -269,6 +270,7 @@ class Step:
             with_param: Union[str, list,
                               InputParameter, OutputParameter] = None,
             continue_on_failed: bool = False,
+            continue_on_error: bool = False,
             continue_on_num_success: Optional[int] = None,
             continue_on_success_ratio: Optional[float] = None,
             with_sequence: Optional[V1alpha1Sequence] = None,
@@ -289,6 +291,7 @@ class Step:
         self.inputs.set_step(self)
         self.outputs.set_step(self)
         self.continue_on_failed = continue_on_failed
+        self.continue_on_error = continue_on_error
         self.continue_on_num_success = continue_on_num_success
         self.continue_on_success_ratio = continue_on_success_ratio
         self.check_step = None
@@ -1117,7 +1120,8 @@ class Step:
             ), when=self.when, with_param=self.with_param,
             with_sequence=None if self.with_sequence is None else
             self.with_sequence.convert_to_argo(),
-            continue_on=V1alpha1ContinueOn(failed=self.continue_on_failed)
+            continue_on=V1alpha1ContinueOn(failed=self.continue_on_failed,
+                                           error=self.continue_on_error)
         )
 
     def run(self, context):
@@ -1532,11 +1536,11 @@ class Step:
             stderr=subprocess.STDOUT,
         ) as p:
             with open("%s/log.txt" % stepdir, "w") as f:
-                line = p.stdout.readline().decode(sys.stdin.encoding)
+                line = p.stdout.readline().decode(sys.stdout.encoding)
                 while line:
                     sys.stdout.write(line)
                     f.write(line)
-                    line = p.stdout.readline().decode(sys.stdin.encoding)
+                    line = p.stdout.readline().decode(sys.stdout.encoding)
             p.wait()
             ret_code = p.poll()
         if ret_code != 0:
