@@ -5,6 +5,7 @@ import logging
 import os
 import pkgutil
 import random
+import shlex
 import shutil
 import string
 import subprocess
@@ -477,6 +478,8 @@ def run_command(
     cmd: Union[List[str], str],
     raise_error: bool = True,
     input: Optional[str] = None,
+    try_bash: bool = False,
+    interactive: bool = True,
     **kwargs,
 ) -> Tuple[int, str, str]:
     """
@@ -490,6 +493,8 @@ def run_command(
         Wheter to raise an error if the command failed
     input: str, optional
         Input string for the command
+    try_bash: bool
+        Try to use bash if bash exists, otherwise use sh
     **kwargs:
         Arguments in subprocess.Popen
 
@@ -512,6 +517,13 @@ def run_command(
     elif isinstance(cmd, list):
         cmd = [str(x) for x in cmd]
 
+    if try_bash:
+        arg = "-ic" if interactive else "-c"
+        script = "if command -v bash 2>&1 >/dev/null; then bash %s " % arg + \
+            shlex.quote(" ".join(cmd)) + "; else " + " ".join(cmd) + "; fi"
+        cmd = [script]
+        kwargs["shell"] = True
+
     sub = subprocess.Popen(
         args=cmd,
         stdin=subprocess.PIPE,
@@ -520,11 +532,11 @@ def run_command(
         **kwargs
     )
     if input is not None:
-        sub.stdin.write(bytes(input, encoding=sys.stdin.encoding))
+        sub.stdin.write(bytes(input, encoding=sys.stdout.encoding))
     out, err = sub.communicate()
     return_code = sub.poll()
-    out = out.decode(sys.stdin.encoding)
-    err = err.decode(sys.stdin.encoding)
+    out = out.decode(sys.stdout.encoding)
+    err = err.decode(sys.stdout.encoding)
     if raise_error:
         assert return_code == 0, "Command %s failed: \n%s" % (cmd, err)
     return return_code, out, err
